@@ -1,13 +1,13 @@
-# $Id: Extrefs.pm,v 1.9 2003/11/22 05:05:10 rcaputo Exp $
+# $Id: Extrefs.pm 2222 2007-08-19 05:02:19Z rcaputo $
 
 # The data necessary to manage tagged extra/external reference counts
 # on sessions, and the accessors to get at them sanely from other
 # files.
 
-package POE::Resources::Extrefs;
+package POE::Resource::Extrefs;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.9 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my($r)=(q$Revision: 2222 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -42,13 +42,17 @@ sub _data_extref_finalize {
 # time the tag is used in the session, then increment the session's
 # reference count as well.  Returns the tag's new reference count.
 #
-# -><- Allows incrementing reference counts on sessions that don't
+# TODO Allows incrementing reference counts on sessions that don't
 # exist, but the public interface catches that.
 
 sub _data_extref_inc {
   my ($self, $session, $tag) = @_;
   my $refcount = ++$kr_extra_refs{$session}->{$tag};
 
+  # TODO We could probably get away with only incrementing the
+  # session's master refcount once, as long as any extra refcount is
+  # positive.  Then the session reference count would be a flag
+  # instead of a counter.
   $self->_data_ses_refcount_inc($session) if $refcount == 1;
 
   if (TRACE_REFCNT) {
@@ -65,13 +69,17 @@ sub _data_extref_inc {
 # if the count reaches zero.  Return the new reference count or undef
 # if the tag doesn't exist.
 #
-# -><- Allows negative reference counts, and the resulting hilarity.
+# TODO Allows negative reference counts, and the resulting hilarity.
 # Hopefully the public interface won't allow it.
 
 sub _data_extref_dec {
   my ($self, $session, $tag) = @_;
 
   if (ASSERT_DATA) {
+    # Prevents autoviv.
+    _trap("<dt> decrementing extref for session without any")
+      unless exists $kr_extra_refs{$session};
+
     unless (exists $kr_extra_refs{$session}->{$tag}) {
       _trap(
         "<dt> decrementing extref for nonexistent tag ``$tag'' in ",
@@ -99,9 +107,12 @@ sub _data_extref_remove {
   my ($self, $session, $tag) = @_;
 
   if (ASSERT_DATA) {
+    # Prevents autoviv.
+    _trap("<dt> removing extref from session without any")
+      unless exists $kr_extra_refs{$session};
     unless (exists $kr_extra_refs{$session}->{$tag}) {
       _trap(
-        "<dt> decrementing extref for nonexistent tag ``$tag'' in ",
+        "<dt> removing extref for nonexistent tag ``$tag'' in ",
         $self->_data_alias_loggable($session)
       );
     }
@@ -117,13 +128,16 @@ sub _data_extref_remove {
 
 sub _data_extref_clear_session {
   my ($self, $session) = @_;
+
+  # TODO - Should there be a _trap here if the session doesn't exist?
+
   return unless exists $kr_extra_refs{$session}; # avoid autoviv
   foreach (keys %{$kr_extra_refs{$session}}) {
     $self->_data_extref_remove($session, $_);
   }
 
   if (ASSERT_DATA) {
-    if (keys %{$kr_extra_refs{$session}}) {
+    if (exists $kr_extra_refs{$session}) {
       _trap(
         "<dt> extref clear did not remove session ",
         $self->_data_alias_loggable($session)
@@ -153,7 +167,7 @@ __END__
 
 =head1 NAME
 
-POE::Resources::Extrefs - tagged "extra" ref. count management for POE::Kernel
+POE::Resource::Extrefs - tagged "extra" ref. count management for POE::Kernel
 
 =head1 SYNOPSIS
 
@@ -182,3 +196,6 @@ Probably others.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
+
+# rocco // vim: ts=2 sw=2 expandtab
+# TODO - Redocument.
